<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="63"/>
        <source>Increase sound volume</source>
        <translation>音量を上げる</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="69"/>
        <source>Decrease sound volume</source>
        <translation>音量を下げる</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="75"/>
        <source>Mute/unmute sound volume</source>
        <translation>ミュート/解除</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="136"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>音量制御: このショートカットは登録することができません: %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="287"/>
        <source>Volume: muted</source>
        <translation>音量: ミュートされています</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="289"/>
        <source>Volume: %1%</source>
        <translation type="unfinished">音量: %1%</translation>
    </message>
    <message>
        <source>Volume: %1</source>
        <translation type="vanished">音量: %1</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>音量制御の設定</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>制御するデバイス</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="28"/>
        <source>Alsa</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>挙動</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>中ボタンのクリックでミュート</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>マウスのクリックで表示</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>100% (0dB)を超える音量を許可</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation>音量の変更時には常に通知する</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="99"/>
        <source>Volume adjust step</source>
        <translation>音量変更のステップ幅</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="118"/>
        <source>External Mixer</source>
        <translation>外部ミキサー</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../../../volumepopup.cpp" line="54"/>
        <source>Launch mixer</source>
        <translation>ミキサーを起動</translation>
    </message>
    <message>
        <location filename="../../../volumepopup.cpp" line="55"/>
        <source>Mi&amp;xer</source>
        <translation>ミキサー(&amp;x)</translation>
    </message>
    <message>
        <source>Mixer</source>
        <translation type="vanished">ミキサー</translation>
    </message>
</context>
</TS>
